powered by
gbd2dmat(X.gbd, skip.balance = FALSE, comm = .SPMD.CT$comm, gbd.major = .DEMO.CT$gbd.major, bldim = .DEMO.CT$bldim, ICTXT = .DEMO.CT$ictxt) dmat2gbd(X.dmat, bal.info = NULL, comm = .SPMD.CT$comm, gbd.major = .DEMO.CT$gbd.major)
load.balance
balance.info
gbd2dmat
dmat2gbd
X.gbd
N.gbd * p
N.gbd
If skip.balance = TRUE, then load.balance will not be called and X.gbd is preassumed to be balanced.
skip.balance = TRUE
For demonstration purpose, these objects should not contains weird values such as NA.
NA
dmat2gbd is supposed returned a balanced gbd matrix if bal.info is not supplied.
bal.info
### Under command mode, run the demo with 4 processors by ### (Use Rscript.exe for windows system) mpiexec -np 4 Rscript -e "demo(gbd_dmat,'pbdDEMO',ask=F,echo=F)"
Run the code above in your browser using DataLab