powered by
spmd2dmat(X.spmd, skip.balance = FALSE, comm = .SPMD.CT$comm, spmd.major = .DEMO.CT$spmd.major, bldim = .DEMO.CT$bldim, ICTXT = .DEMO.CT$ictxt) dmat2spmd(X.dmat, bal.info = NULL, comm = .SPMD.CT$comm, spmd.major = .DEMO.CT$spmd.major)
load.balance
balance.info
spmd2dmat
dmat2spmd
X.spmd
N.spmd * p
N.spmd
If skip.balance = TRUE, then load.balance will not be called and X.spmd is preassumed to be balanced.
skip.balance = TRUE
For demonstration purpose, these objects should not contains weird values such as NA.
NA
dmat2spmd is supposed returned a balanced spmd matrix if bal.info is not supplied.
bal.info
### Under command mode, run the demo with 4 processors by ### (Use Rscript.exe for windows system) mpiexec -np 4 Rscript -e "demo(spmd_dmat,'pbdDEMO',ask=F,echo=F)"
Run the code above in your browser using DataLab